@@ -22,7 +22,7 @@
 #include "wayland.h"
 
 // Creates and returns a new menu.
-struct menu *menu_create() {
+struct menu *menu_create(menu_callback callback) {
 	struct menu *menu = calloc(1, sizeof(struct menu));
 	menu->strncmp = strncmp;
 	menu->font = "monospace 10";
@@ -32,6 +32,7 @@ struct menu *menu_create() {
 	menu->promptfg = 0xeeeeeeff;
 	menu->selectionbg = 0x005577ff;
 	menu->selectionfg = 0xeeeeeeff;
+	menu->callback = callback;
 	return menu;
 }
 
@@ -85,11 +86,11 @@ static bool parse_color(const char *color, uint32_t *result) {
 // Parse menu options from command line arguments.
 void menu_getopts(struct menu *menu, int argc, char *argv[]) {
 	const char *usage =
-		"Usage: wmenu [-biPvx] [-f font] [-l lines] [-o output] [-p prompt]\n"
+		"Usage: wmenu [-biPv] [-f font] [-l lines] [-o output] [-p prompt]\n"
 		"\t[-N color] [-n color] [-M color] [-m color] [-S color] [-s color]\n";
 
 	int opt;
-	while ((opt = getopt(argc, argv, "bhivf:l:o:p:N:n:M:m:S:s:")) != -1) {
+	while ((opt = getopt(argc, argv, "bhiPvf:l:o:p:N:n:M:m:S:s:")) != -1) {
 		switch (opt) {
 		case 'b':
 			menu->bottom = true;
@@ -97,6 +98,9 @@ void menu_getopts(struct menu *menu, int argc, char *argv[]) {
 		case 'i':
 			menu->strncmp = strncasecmp;
 			break;
+		case 'P':
+			menu->passwd = true;
+			break;
 		case 'v':
 			puts("wmenu " VERSION);
 			exit(EXIT_SUCCESS);
@@ -568,18 +572,10 @@ void menu_keypress(struct menu *menu, enum wl_keyboard_key_state key_state,
 	case XKB_KEY_Return:
 	case XKB_KEY_KP_Enter:
 		if (shift) {
-			puts(menu->input);
-			fflush(stdout);
-			menu->exit = true;
-		} else if (menu->callback) {
-			menu->callback(menu);
+			menu->callback(menu, menu->input, true);
 		} else {
 			char *text = menu->sel ? menu->sel->text : menu->input;
-			puts(text);
-			fflush(stdout);
-			if (!ctrl) {
-				menu->exit = true;
-			}
+			menu->callback(menu, text, !ctrl);
 		}
 		break;
 	case XKB_KEY_Left:
