@@ -1,8 +1,6 @@
-#ifndef DMENU_PANGO_H
-#define DMENU_PANGO_H
-#include <stdarg.h>
+#ifndef WMENU_PANGO_H
+#define WMENU_PANGO_H
 #include <stdbool.h>
-#include <stdint.h>
 #include <cairo/cairo.h>
 #include <pango/pangocairo.h>
 
